@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006-2007, 2010 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOSHAPECONTAINERMODEL_H
@@ -116,14 +103,6 @@ public:
      */
     virtual bool inheritsTransform(const KoShape *shape) const = 0;
 
-    /**
-     * Return wheather the child has the effective state of being locked for user modifications.
-     * The model has to call KoShape::isGeometryProtected() and base its return value upon that, it can
-     *  additionally find rules on wheather the child is locked based on the container state.
-     * @param child the shape that the user wants to move.
-     */
-    virtual bool isChildLocked(const KoShape *child) const = 0;
-
     /**
      * Return the current number of children registered.
      * @return the current number of children registered.
@@ -163,8 +142,8 @@ public:
      * to inform the container of such a change.  The change has already happened at the
      * time this method is called.
      * The base implementation notifies the grand parent of the shape that there was a
-     * change in a shape. A reimplentation if this function should call this method when
-     * overwriding the function.
+     * change in a shape. A reimplementation if this function should call this method when
+     * overriding the function.
      *
      * @param shape the shape that has been changed
      * @param type this enum shows which change the shape has had.
