@@ -1,26 +1,13 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright     2007       David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "KoJsonTrader.h"
 
-#include "KritaPluginDebug.h"
+#include "kis_debug.h"
 
 #include <QCoreApplication>
 #include <QPluginLoader>
@@ -32,10 +19,19 @@
 #include <QGlobalStatic>
 #include <QMutexLocker>
 
+struct KoJsonTrader::PluginCacheEntry
+{
+    QString filePath;
+    QJsonArray serviceTypes;
+    QStringList mimeTypes;
+    QSharedPointer<QPluginLoader> loader;
+};
+
+
 KoJsonTrader::KoJsonTrader()
 {
     // Allow a command line variable KRITA_PLUGIN_PATH to override the automatic search
-    auto requestedPath = QProcessEnvironment::systemEnvironment().value("KRITA_PLUGIN_PATH");
+    QString requestedPath = QProcessEnvironment::systemEnvironment().value("KRITA_PLUGIN_PATH");
     if (!requestedPath.isEmpty()) {
         m_pluginPath = requestedPath;
     }
@@ -45,26 +41,27 @@ KoJsonTrader::KoJsonTrader()
 
         QDir appDir(qApp->applicationDirPath());
         appDir.cdUp();
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
         // Help Krita run without deployment
         QDir d(appDir);
         d.cd("../../../");
         searchDirs << d;
 #endif
-        searchDirs << appDir;
-        // help plugin trader find installed plugins when run from uninstalled tests
-#ifdef CMAKE_INSTALL_PREFIX
-        searchDirs << QDir(CMAKE_INSTALL_PREFIX);
+
+#ifdef Q_OS_ANDROID
+        appDir.cdUp();
 #endif
+        searchDirs << appDir;
+
         Q_FOREACH (const QDir& dir, searchDirs) {
             const QStringList nameFilters = {
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
                 "*PlugIns*",
 #endif
                 "lib*",
             };
             Q_FOREACH (const QFileInfo &info, dir.entryInfoList(nameFilters, QDir::Dirs | QDir::NoDotAndDotDot)) {
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
                 if (info.fileName().contains("PlugIns")) {
                     m_pluginPath = info.absoluteFilePath();
                     break;
@@ -75,6 +72,19 @@ KoJsonTrader::KoJsonTrader()
 #endif
                     QDir libDir(info.absoluteFilePath());
 
+#ifdef Q_OS_ANDROID
+#if defined(Q_PROCESSOR_ARM_64)
+                    libDir.cd("arm64-v8a");
+#elif defined(Q_PROCESSOR_ARM)
+                    libDir.cd("armeabi-v7a");
+#elif defined(Q_PROCESSOR_X86_64)
+                    libDir.cd("x86_64");
+#elif defined(Q_PROCESSOR_x86)
+                    libDir.cd("x86");
+#endif
+                    m_pluginPath = libDir.absolutePath();
+                    break;
+#else
                     // on many systems this will be the actual lib dir (and krita subdir contains plugins)
                     if (libDir.cd("kritaplugins")) {
                         m_pluginPath = libDir.absolutePath();
@@ -95,6 +105,7 @@ KoJsonTrader::KoJsonTrader()
                     if (!m_pluginPath.isEmpty()) {
                         break;
                     }
+#endif
                 }
             }
 
@@ -102,10 +113,17 @@ KoJsonTrader::KoJsonTrader()
                 break;
             }
         }
-        debugPlugin << "KoJsonTrader will load its plugins from" << m_pluginPath;
+        dbgPlugins << "KoJsonTrader will load its plugins from" << m_pluginPath;
     }
+
+    initializePluginLoaderCache();
 }
 
+KoJsonTrader::~KoJsonTrader()
+{
+}
+
+
 Q_GLOBAL_STATIC(KoJsonTrader, s_instance)
 
 KoJsonTrader* KoJsonTrader::instance()
@@ -113,49 +131,103 @@ KoJsonTrader* KoJsonTrader::instance()
     return s_instance;
 }
 
-QList<QPluginLoader *> KoJsonTrader::query(const QString &servicetype, const QString &mimetype) const
+void KoJsonTrader::initializePluginLoaderCache()
 {
     QMutexLocker l(&m_mutex);
 
+    KIS_SAFE_ASSERT_RECOVER_RETURN(m_pluginLoaderCache.isEmpty());
+
     QList<QPluginLoader *>list;
     QDirIterator dirIter(m_pluginPath, QDirIterator::Subdirectories);
     while (dirIter.hasNext()) {
         dirIter.next();
+#ifdef Q_OS_ANDROID
+        // files starting with lib_krita are plugins, it is needed because of the loading rules in NDK
+        if (dirIter.fileInfo().isFile() && dirIter.fileName().startsWith("lib_krita")) {
+#elif defined(_MSC_VER)
+        if (dirIter.fileInfo().isFile() && dirIter.fileName().startsWith("krita") && !dirIter.fileName().endsWith(".pdb") && !dirIter.fileName().endsWith(".lib")) {
+#else
         if (dirIter.fileInfo().isFile() && dirIter.fileName().startsWith("krita") && !dirIter.fileName().endsWith(".debug")) {
-            debugPlugin << dirIter.fileName();
-            QPluginLoader *loader = new QPluginLoader(dirIter.filePath());
+#endif
+
+            dbgPlugins << dirIter.fileName();
+            QScopedPointer<QPluginLoader> loader(new QPluginLoader(dirIter.filePath()));
             QJsonObject json = loader->metaData().value("MetaData").toObject();
 
-            debugPlugin << mimetype << json << json.value("X-KDE-ServiceTypes");
+            dbgPlugins << json << json.value("X-KDE-ServiceTypes");
 
             if (json.isEmpty()) {
-                delete loader;
                 qWarning() << dirIter.filePath() << "has no json!";
-            }
-            else {
+                continue;
+            } else {
                 QJsonArray  serviceTypes = json.value("X-KDE-ServiceTypes").toArray();
                 if (serviceTypes.isEmpty()) {
                     qWarning() << dirIter.fileName() << "has no X-KDE-ServiceTypes";
-                }
-                if (!serviceTypes.contains(QJsonValue(servicetype))) {
-                    delete loader;
                     continue;
                 }
 
-                if (!mimetype.isEmpty()) {
-                    QStringList mimeTypes = json.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
-                    mimeTypes += json.value("MimeType").toString().split(';');
-                    mimeTypes += json.value("X-KDE-NativeMimeType").toString();
-                    if (! mimeTypes.contains(mimetype)) {
-                        qWarning() << dirIter.filePath() << "doesn't contain mimetype" << mimetype << "in" << mimeTypes;
-                        delete loader;
-                        continue;
-                    }
-                }
-                list.append(loader);
+                QStringList mimeTypes = json.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
+                mimeTypes += json.value("MimeType").toString().split(';');
+                mimeTypes += json.value("X-KDE-NativeMimeType").toString();
+
+                PluginCacheEntry cacheEntry;
+                cacheEntry.filePath = dirIter.filePath();
+                cacheEntry.serviceTypes = serviceTypes;
+                cacheEntry.mimeTypes = mimeTypes;
+                cacheEntry.loader = toQShared(loader.take());
+                m_pluginLoaderCache << cacheEntry;
             }
         }
-
     }
+}
+
+QList<KoJsonTrader::Plugin> KoJsonTrader::query(const QString &servicetype, const QString &mimetype)
+{
+    QMutexLocker l(&m_mutex);
+
+    QList<Plugin> list;
+    Q_FOREACH(const PluginCacheEntry &plugin, m_pluginLoaderCache) {
+        if (!plugin.serviceTypes.contains(QJsonValue(servicetype))) {
+            continue;
+        }
+
+        if (!mimetype.isEmpty() && !plugin.mimeTypes.contains(mimetype)) {
+            continue;
+        }
+
+        list << Plugin(plugin.loader, &m_mutex);
+    }
+
     return list;
 }
+
+KoJsonTrader::Plugin::Plugin(QSharedPointer<QPluginLoader> loader, QMutex *mutex)
+    : m_loader(loader),
+      m_mutex(mutex)
+{
+}
+
+KoJsonTrader::Plugin::~Plugin()
+{
+}
+
+QObject *KoJsonTrader::Plugin::instance() const
+{
+    QMutexLocker l(m_mutex);
+    return m_loader->instance();
+}
+
+QJsonObject KoJsonTrader::Plugin::metaData() const
+{
+    return m_loader->metaData();
+}
+
+QString KoJsonTrader::Plugin::fileName() const
+{
+    return m_loader->fileName();
+}
+
+QString KoJsonTrader::Plugin::errorString() const
+{
+    return m_loader->errorString();
+}
