@@ -1,24 +1,13 @@
 /*
- *  Copyright (c) 2016 Boudewijn Rempt <boud@valdyas.org>
+ *  SPDX-FileCopyrightText: 2016 Boudewijn Rempt <boud@valdyas.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "Krita.h"
 
 #include <QPointer>
 #include <QVariant>
+#include <QStringList>
 
 #include <ksharedconfig.h>
 #include <kconfiggroup.h>
@@ -46,14 +35,17 @@
 #include <kis_filter_configuration.h>
 #include <kis_properties_configuration.h>
 #include <kis_config.h>
-#include <KisResourceServerProvider.h>
 #include <kis_workspace_resource.h>
 #include <brushengine/kis_paintop_preset.h>
-#include <kis_brush_server.h>
+#include <KisBrushServerProvider.h>
 #include <KoResourceServerProvider.h>
+#include <KisResourceServerProvider.h>
+#include <KisBrushServerProvider.h>
 #include <kis_action_registry.h>
 #include <kis_icon_utils.h>
-#include <KisPart.h>
+
+#include <KisResourceModel.h>
+#include <KisGlobalResourcesInterface.h>
 
 #include "View.h"
 #include "Document.h"
@@ -78,7 +70,7 @@ Krita::Krita(QObject *parent)
     , d(new Private)
 {
     qRegisterMetaType<Notifier*>();
-    connect(KisPart::instance(), SIGNAL(sigWindowAdded(KisMainWindow*)), SLOT(mainWindowAdded(KisMainWindow*)));
+    connect(KisPart::instance(), SIGNAL(sigMainWindowIsBeingCreated(KisMainWindow*)), SLOT(mainWindowIsBeingCreated(KisMainWindow*)));
 }
 
 Krita::~Krita()
@@ -94,7 +86,7 @@ QList<QAction *> Krita::actions() const
     if (!mainWindow) {
         return QList<QAction*>();
     }
-    KActionCollection *actionCollection = mainWindow->actionCollection();
+    KisKActionCollection *actionCollection = mainWindow->actionCollection();
     return actionCollection->actions();
 }
 
@@ -104,7 +96,7 @@ QAction *Krita::action(const QString &name) const
     if (!mainWindow) {
         return 0;
     }
-    KActionCollection *actionCollection = mainWindow->actionCollection();
+    KisKActionCollection *actionCollection = mainWindow->actionCollection();
     QAction *action = actionCollection->action(name);
     return action;
 }
@@ -120,7 +112,8 @@ Document* Krita::activeDocument() const
         return 0;
     }
     KisDocument *document = view->document();
-    return new Document(document);
+    Document *d = new Document(document, false);
+    return d;
 }
 
 void Krita::setActiveDocument(Document* value)
@@ -148,7 +141,7 @@ QList<Document *> Krita::documents() const
 {
     QList<Document *> ret;
     foreach(QPointer<KisDocument> doc, KisPart::instance()->documents()) {
-        ret << new Document(doc);
+        ret << new Document(doc, false);
     }
     return ret;
 }
@@ -167,7 +160,7 @@ Filter *Krita::filter(const QString &name) const
     Filter *filter = new Filter();
     filter->setName(name);
     KisFilterSP f = KisFilterRegistry::instance()->value(name);
-    KisFilterConfigurationSP fc = f->defaultConfiguration();
+    KisFilterConfigurationSP fc = f->defaultConfiguration(KisGlobalResourcesInterface::instance());
     InfoObject *info = new InfoObject(fc);
     filter->setConfiguration(info);
     return filter;
@@ -180,7 +173,11 @@ QStringList Krita::colorModels() const
     Q_FOREACH(KoID id, ids) {
         colorModelsIds << id.id();
     }
-    return colorModelsIds.toList();
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+    return QStringList(colorModelsIds.begin(), colorModelsIds.end());
+#else
+    return QStringList::fromSet(colorModelsIds);
+#endif
 }
 
 QStringList Krita::colorDepths(const QString &colorModel) const
@@ -190,7 +187,11 @@ QStringList Krita::colorDepths(const QString &colorModel) const
     Q_FOREACH(KoID id, ids) {
         colorDepthsIds << id.id();
     }
-    return colorDepthsIds.toList();
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+    return QStringList(colorDepthsIds.begin(), colorDepthsIds.end());
+#else
+    return QStringList::fromSet(colorDepthsIds);
+#endif
 }
 
 QStringList Krita::filterStrategies() const
@@ -206,12 +207,19 @@ QStringList Krita::profiles(const QString &colorModel, const QString &colorDepth
     Q_FOREACH(const KoColorProfile *profile, profiles) {
         profileNames << profile->name();
     }
-    return profileNames.toList();
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+    QStringList r(profileNames.begin(), profileNames.end());
+#else
+    QStringList r = QStringList::fromSet(profileNames);
+#endif
+    r.sort();
+    return r;
 }
 
 bool Krita::addProfile(const QString &profilePath)
 {
     KoColorSpaceEngine *iccEngine = KoColorSpaceEngineRegistry::instance()->get("icc");
+    KIS_ASSERT(iccEngine);
     return iccEngine->addProfile(profilePath);
 }
 
@@ -252,49 +260,58 @@ QList<Window*>  Krita::windows() const
     return ret;
 }
 
-QMap<QString, Resource *> Krita::resources(const QString &type) const
+QMap<QString, Resource*> Krita::resources(QString &type) const
 {
-    QMap<QString, Resource *> resources = QMap<QString, Resource *> ();
+    QMap<QString, Resource*> resources;
+    KisResourceModel *resourceModel = 0;
+    if (type == "pattern") {
+        resourceModel = KoResourceServerProvider::instance()->patternServer()->resourceModel();
+        type = ResourceType::Patterns;
+    }
+    else if (type == "gradient") {
+        type = ResourceType::Gradients;
+        resourceModel = KoResourceServerProvider::instance()->gradientServer()->resourceModel();
+    }
+    else if (type == "brush") {
+        resourceModel = KisBrushServerProvider::instance()->brushServer()->resourceModel();
+        type = ResourceType::Brushes;
+    }
+    else if (type == "palette") {
+        resourceModel = KoResourceServerProvider::instance()->paletteServer()->resourceModel();
+        type = ResourceType::Palettes;
+    }
+    else if (type == "workspace") {
+        resourceModel = KisResourceServerProvider::instance()->workspaceServer()->resourceModel();
+        type = ResourceType::Workspaces;
+    }
+    else if (type == "preset") {
+        resourceModel = KisResourceServerProvider::instance()->paintOpPresetServer()->resourceModel();
+    }
 
-    if (type.toLower() == "pattern") {
-        KoResourceServer<KoPattern>* server = KoResourceServerProvider::instance()->patternServer();
-        Q_FOREACH (KoResource *res, server->resources()) {
-            resources[res->name()] = new Resource(res);
-        }
-    }
-    else if (type.toLower() == "gradient") {
-        KoResourceServer<KoAbstractGradient>* server = KoResourceServerProvider::instance()->gradientServer();
-        Q_FOREACH (KoResource *res, server->resources()) {
-            resources[res->name()] = new Resource(res);
-        }
-    }
-    else if (type.toLower() == "brush") {
-        KisBrushResourceServer* server = KisBrushServer::instance()->brushServer();
-        Q_FOREACH (KisBrushSP res, server->resources()) {
-            resources[res->name()] = new Resource(res.data());
-        }
-    }
-    else if (type.toLower() == "preset") {
-        KisPaintOpPresetResourceServer* server = KisResourceServerProvider::instance()->paintOpPresetServer();
-        Q_FOREACH (KisPaintOpPresetSP res, server->resources()) {
-            resources[res->name()] = new Resource(res.data());
-        }
-    }
-    else if (type.toLower() == "palette") {
-        KoResourceServer<KoColorSet>* server = KoResourceServerProvider::instance()->paletteServer();
-        Q_FOREACH (KoResource *res, server->resources()) {
-            resources[res->name()] = new Resource(res);
-        }
-    }
-    else if (type.toLower() == "workspace") {
-        KoResourceServer< KisWorkspaceResource >* server = KisResourceServerProvider::instance()->workspaceServer();
-        Q_FOREACH (KoResource *res, server->resources()) {
-            resources[res->name()] = new Resource(res);
+    if (resourceModel) {
+        for (int i = 0; i < resourceModel->rowCount(); ++i) {
+
+            QModelIndex idx = resourceModel->index(i, 0);
+            int id = resourceModel->data(idx, Qt::UserRole + KisAbstractResourceModel::Id).toInt();
+            QString name  = resourceModel->data(idx, Qt::UserRole + KisAbstractResourceModel::Name).toString();
+            QString filename  = resourceModel->data(idx, Qt::UserRole + KisAbstractResourceModel::Filename).toString();
+            QImage image = resourceModel->data(idx, Qt::UserRole + KisAbstractResourceModel::Thumbnail).value<QImage>();
+
+            resources[name] = new Resource(id, type, name, filename, image, 0);
         }
     }
+
     return resources;
 }
 
+
+QList<QDockWidget*> Krita::dockers() const
+{
+    KisMainWindow *mainWindow = KisPart::instance()->currentMainwindow();
+    return mainWindow->dockWidgets();
+}
+
+
 QStringList Krita::recentDocuments() const
 {
     KConfigGroup grp = KSharedConfig::openConfig()->group(QString("RecentFiles"));
@@ -310,7 +327,9 @@ QStringList Krita::recentDocuments() const
 Document* Krita::createDocument(int width, int height, const QString &name, const QString &colorModel, const QString &colorDepth, const QString &profile, double resolution)
 {
     KisDocument *document = KisPart::instance()->createDocument();
-    KisPart::instance()->addDocument(document);
+    document->setObjectName(name);
+
+    KisPart::instance()->addDocument(document, false);
     const KoColorSpace *cs = KoColorSpaceRegistry::instance()->colorSpace(colorModel, colorDepth, profile);
     Q_ASSERT(cs);
 
@@ -318,25 +337,27 @@ Document* Krita::createDocument(int width, int height, const QString &name, cons
     qc.setAlpha(0);
     KoColor bgColor(qc, cs);
 
-    if (!document->newImage(name, width, height, cs, bgColor, true, 1, "", double(resolution / 72) )) {
-        qDebug() << "Could not create a new image";
+    if (!document->newImage(name, width, height, cs, bgColor, KisConfig::RASTER_LAYER, 1, "", double(resolution / 72) )) {
         return 0;
     }
 
     Q_ASSERT(document->image());
-    qDebug() << document->image()->objectName();
+    Document *doc = new Document(document, true);
 
-    return new Document(document);
+    return doc;
 }
 
 Document* Krita::openDocument(const QString &filename)
 {
     KisDocument *document = KisPart::instance()->createDocument();
     document->setFileBatchMode(this->batchmode());
+    if (!document->openPath(filename, KisDocument::DontAddToRecent)) {
+        delete document;
+        return 0;
+    }
     KisPart::instance()->addDocument(document);
-    document->openUrl(QUrl::fromLocalFile(filename), KisDocument::DontAddToRecent);
     document->setFileBatchMode(false);
-    return new Document(document);
+    return new Document(document, true);
 }
 
 Window* Krita::openWindow()
@@ -415,10 +436,22 @@ QString Krita::krita_i18n(const QString &text)
     return i18n(text.toUtf8().constData());
 }
 
-void Krita::mainWindowAdded(KisMainWindow *kisWindow)
+QString Krita::krita_i18nc(const QString &context, const QString &text)
+{
+    return i18nc(context.toUtf8().constData(), text.toUtf8().constData());
+}
+
+QString Krita::getAppDataLocation()
+{
+    return KoResourcePaths::getAppDataLocation();
+}
+
+void Krita::mainWindowIsBeingCreated(KisMainWindow *kisWindow)
 {
     Q_FOREACH(Extension *extension, d->extensions) {
         Window window(kisWindow);
         extension->createActions(&window);
     }
 }
+
+#include "moc_Krita.cpp"
