@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
- *  Copyright (c) 2017 Scott Petrovic <scottpetrovic@gmail.com>
+ *  SPDX-FileCopyrightText: 2008 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2017 Scott Petrovic <scottpetrovic@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef _KIS_PAINTING_ASSISTANT_H_
@@ -26,9 +14,12 @@
 #include <QFile>
 #include <QObject>
 #include <QColor>
+#include <QXmlStreamWriter>
+#include <QMap>
 
 #include <kritaui_export.h>
 #include <kis_shared.h>
+#include <kis_types.h>
 
 class QPainter;
 class QRect;
@@ -73,12 +64,19 @@ public:
     void uncache();
     KisPaintingAssistantHandle& operator=(const QPointF&);
     void setType(char type);
-    char handleType();
+    char handleType() const;
+
+    /**
+     * Returns the pointer to the "chief" assistant,
+     * which is supposed to handle transformations of the
+     * handle, when all the assistants are transformed
+     */
+    KisPaintingAssistant* chiefAssistant() const;
 
 private:
     void registerAssistant(KisPaintingAssistant*);
     void unregisterAssistant(KisPaintingAssistant*);
-    bool containsAssistant(KisPaintingAssistant*);
+    bool containsAssistant(KisPaintingAssistant*) const;
 
 private:
     struct Private;
@@ -94,26 +92,56 @@ class KRITAUI_EXPORT KisPaintingAssistant
 public:
     KisPaintingAssistant(const QString& id, const QString& name);
     virtual ~KisPaintingAssistant();
+    virtual KisPaintingAssistantSP clone(QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap) const = 0;
     const QString& id() const;
     const QString& name() const;
     bool isSnappingActive() const;
     void setSnappingActive(bool set);
 
+
     /**
      * Adjust the position given in parameter.
      * @param point the coordinates in point in the document reference
      * @param strokeBegin the coordinates of the beginning of the stroke
+     * @param snapToAny because now assistants can be composited out of multiple inside assistants.
+     *         snapToAny true means that you can use any of the inside assistant, while it being false
+     *         means you should use the last used one. The logic determining when it happens (first stroke etc.)
+     *         is in the decoration, so those two options are enough.
      */
-    virtual QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin) = 0;
-    virtual void endStroke() { }
-    virtual QPointF buttonPosition() const = 0;
+    virtual QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, bool snapToAny) = 0;
+    virtual void endStroke() {}
+    virtual void setAdjustedBrushPosition(const QPointF position) { Q_UNUSED(position) }
+    virtual void setFollowBrushPosition(bool follow) { Q_UNUSED(follow) }
+    virtual QPointF getEditorPosition() const = 0; // Returns editor widget position in document-space coordinates.
     virtual int numHandles() const = 0;
+
+    /**
+     * @brief canBeLocal
+     * @return if the assistant can be potentially a "local assistant" (limited to rectangular area) or not
+     */
+    virtual bool canBeLocal() const;
+    /**
+     * @brief isLocal
+     * @return if the assistant is limited to a rectangular area or not
+     */
+    bool isLocal() const;
+    /**
+     * @brief setLocal
+     * @param value set the indication if the assistant is limited to a rectangular area or not
+     */
+    void setLocal(bool value);
+
     void replaceHandle(KisPaintingAssistantHandleSP _handle, KisPaintingAssistantHandleSP _with);
     void addHandle(KisPaintingAssistantHandleSP handle, HandleType type);
 
-    /// grabs the assistant color/opacity specified from the tool options
-    /// each assistant might have to use this differently, so just save a reference
-    void setAssistantColor(QColor color);
+    QPointF viewportConstrainedEditorPosition(const KisCoordinatesConverter* converter, const QSize editorSize);
+
+    QColor effectiveAssistantColor() const;
+    bool useCustomColor();
+    void setUseCustomColor(bool useCustomColor);
+    void setAssistantCustomColor(QColor color);
+    QColor assistantCustomColor();
+    void setAssistantGlobalColorCache(const QColor &color);
 
     virtual void drawAssistant(QPainter& gc, const QRectF& updateRect, const KisCoordinatesConverter *converter, bool cached = true,KisCanvas2 *canvas=0, bool assistantVisible=true, bool previewVisible=true);
     void uncache();
@@ -121,8 +149,13 @@ public:
     QList<KisPaintingAssistantHandleSP> handles();
     const QList<KisPaintingAssistantHandleSP>& sideHandles() const;
     QList<KisPaintingAssistantHandleSP> sideHandles();
+
     QByteArray saveXml( QMap<KisPaintingAssistantHandleSP, int> &handleMap);
+    virtual void saveCustomXml(QXmlStreamWriter* xml); //in case specific assistants have custom properties (like vanishing point)
+
     void loadXml(KoStore *store, QMap<int, KisPaintingAssistantHandleSP> &handleMap, QString path);
+    virtual bool loadCustomXml(QXmlStreamReader* xml);
+
     void saveXmlList(QDomDocument& doc, QDomElement& ssistantsElement, int count);
     void findPerspectiveAssistantHandleLocation();
     KisPaintingAssistantHandleSP oppHandleOne();
@@ -163,6 +196,11 @@ public:
     /// it will return false if we are in the middle of creating the assistant.
     virtual bool isAssistantComplete() const;
 
+    /// Transform the assistant using the given \p transform. Please note that \p transform
+    /// should be in 'document' coordinate system.
+    /// Used with image-wide transformations.
+    virtual void transform(const QTransform &transform);
+
 public:
     /**
      * This will render the final output. The drawCache does rendering most of the time so be sure to check that
@@ -172,6 +210,8 @@ public:
     static double norm2(const QPointF& p);
 
 protected:
+    explicit KisPaintingAssistant(const KisPaintingAssistant &rhs, QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap);
+
     virtual QRect boundingRect() const;
 
     /// performance layer where the graphics can be drawn from a cache instead of generated every render update
@@ -182,6 +222,42 @@ protected:
 
     QPointF pixelToView(const QPoint pixelCoords) const;
 
+    /**
+     * @brief firstLocalHandle
+     * Note: this doesn't guarantee it will be the topleft corner!
+     * For that, use getLocalRect().topLeft()
+     * The only purpose of those functions to exist is to be able to
+     * put getLocalRect() function in the KisPaintingAssistant
+     * instead of reimplementing it in every specific assistant.
+     * @return the first handle of the rectangle of the limited area
+     */
+    virtual KisPaintingAssistantHandleSP firstLocalHandle() const;
+    /**
+     * @brief secondLocalHandle
+     * Note: this doesn't guarantee it will be the bottomRight corner!
+     * For that, use getLocalRect().bottomRight()
+     * (and remember that for QRect bottomRight() works differently than for QRectF,
+     * so don't convert to QRect before accessing the corner)
+     * @return
+     */
+    virtual KisPaintingAssistantHandleSP secondLocalHandle() const;
+    /**
+     * @brief getLocalRect
+     * The function deals with local handles not being topLeft and bottomRight
+     * gracefully and returns a correct rectangle.
+     * Thanks to that the user can place handles in a "wrong" order or move them around
+     * but the local rectangle will still be correct.
+     * @return the rectangle of the area that the assistant is limited to
+     */
+    QRectF getLocalRect() const;
+
+
+public:
+    /// clones the list of assistants
+    /// the originally shared handles will still be shared
+    /// the cloned assistants do not share any handle with the original assistants
+    static QList<KisPaintingAssistantSP> cloneAssistantList(const QList<KisPaintingAssistantSP> &list);
+
 private:
     struct Private;
     Private* const d;
