@@ -1,26 +1,14 @@
 /* This file is part of the KDE libraries
-    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-              (C) 1999 Simon Hausmann <hausmann@kde.org>
-              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
-              (C) 2000 Kurt Granroth <granroth@kde.org>
-              (C) 2000 Michael Koch <koch@kde.org>
-              (C) 2001 Holger Freyther <freyther@kde.org>
-              (C) 2002 Ellis Whitehead <ellis@kde.org>
-              (C) 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Nicolas Hadacek <haadcek@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2000 Michael Koch <koch@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@kde.org>
+    SPDX-FileCopyrightText: 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KACTIONCOLLECTION_H
@@ -28,33 +16,33 @@
 #include "config-xmlgui.h"
 #include <kritawidgetutils_export.h>
 #include <kstandardaction.h>
-#include <QtCore/QObject>
+#include <QObject>
 
 class QAction;
-class KXMLGUIClient;
+class KisKXMLGUIClient;
 class KConfigGroup;
 class QActionGroup;
 class QString;
-class KActionCategory;
+class KisKActionCategory;
 
 /**
  * \short A container for a set of QAction objects.
  *
- * KActionCollection manages a set of QAction objects.  It
+ * KisKActionCollection manages a set of QAction objects.  It
  * allows them to be grouped for organized presentation of configuration to the user,
  * saving + loading of configuration, and optionally for automatic plugging into
  * specified widget(s).
  *
- * Additionally, KActionCollection provides several convenience functions for locating
+ * Additionally, KisKActionCollection provides several convenience functions for locating
  * named actions, and actions grouped by QActionGroup.
  *
  * \note If you create your own action collection and need to assign shortcuts
  * to the actions within, you have to call associateWidget() or
  * addAssociatedWidget() to have them working.
  */
-class KRITAWIDGETUTILS_EXPORT KActionCollection : public QObject
+class KRITAWIDGETUTILS_EXPORT KisKActionCollection : public QObject
 {
-    friend class KXMLGUIClient;
+    friend class KisKXMLGUIClient;
 
     Q_OBJECT
 
@@ -65,17 +53,17 @@ public:
      * Constructor.  Allows specification of a component name other than the default
      * application name, where needed (remember to call setComponentDisplayName() too).
      */
-    explicit KActionCollection(QObject *parent, const QString &cName = QString());
+    explicit KisKActionCollection(QObject *parent, const QString &cName = QString());
 
     /**
      * Destructor.
      */
-    ~KActionCollection() override;
+    ~KisKActionCollection() override;
 
     /**
      * Access the list of all action collections in existence for this app
      */
-    static const QList<KActionCollection *> &allCollections();
+    static const QList<KisKActionCollection *> &allCollections();
 
     /**
      * Clears the entire action collection, deleting all actions.
@@ -209,10 +197,10 @@ public:
     /**
      * Set the \a componentName associated with this action collection.
      *
-     * \warning Don't call this method on a KActionCollection that contains
+     * \warning Don't call this method on a KisKActionCollection that contains
      * actions. This is not supported.
      *
-     * \param componentData the name which is to be associated with this action collection,
+     * \param componentName the name which is to be associated with this action collection,
      * or QString() to indicate the app name. This is used to load/save settings into XML files.
      * KXmlGuiClient::setComponentName takes care of calling this.
      */
@@ -232,15 +220,15 @@ public:
     QString componentDisplayName() const;
 
     /**
-     * The parent KXMLGUIClient, or null if not available.
+     * The parent KisKXMLGUIClient, or null if not available.
      */
-    const KXMLGUIClient *parentGUIClient() const;
+    const KisKXMLGUIClient *parentGUIClient() const;
 
 
     /**
      * Returns the KActionCategories inside this collection
      */
-    QList<KActionCategory *> categories() const;
+    QList<KisKActionCategory *> categories() const;
 
 
     /**
@@ -248,7 +236,7 @@ public:
      *
      * Creates a new category if one does not exist.
      */
-    KActionCategory *getCategory(const QString &categoryName);
+    KisKActionCategory *getCategory(const QString &categoryName);
 
 Q_SIGNALS:
     /**
@@ -256,12 +244,6 @@ Q_SIGNALS:
      */
     void inserted(QAction *action);
 
-    /**
-     * Indicates that \a action was removed from this action collection.
-     * @deprecated
-     */
-    QT_MOC_COMPAT void removed(QAction *action);
-
     /**
      * Indicates that \a action was highlighted (hovered over).
      * @deprecated Replaced by actionHovered(QAction* action);
@@ -305,9 +287,6 @@ public:
      * Inserting an action under a name that is already used for another action will replace
      * the other action in the collection (but will not delete it).
      *
-     * If KAuthorized::authorizeKAction() reports that the action is not
-     * authorized, it will be disabled and hidden.
-     *
      * @param name The name by which the action be retrieved again from the collection.
      * @param action The action to add.
      * @return the same as the action given as parameter. This is just for convenience
@@ -505,10 +484,10 @@ private:
     Q_PRIVATE_SLOT(d, void _k_actionDestroyed(QObject *))
     Q_PRIVATE_SLOT(d, void _k_associatedWidgetDestroyed(QObject *))
 
-    KActionCollection(const KXMLGUIClient *parent);   // used by KXMLGUIClient
+    KisKActionCollection(const KisKXMLGUIClient *parent);   // used by KisKXMLGUIClient
 
-    friend class KActionCollectionPrivate;
-    class KActionCollectionPrivate *const d;
+    friend class KisKActionCollectionPrivate;
+    class KisKActionCollectionPrivate *const d;
 };
 
 #endif
