@@ -1,24 +1,15 @@
 /*
- *  Copyright (c) 2011 Sven Langkamp <sven.langkamp@gmail.com>
+ *  SPDX-FileCopyrightText: 2011 Sven Langkamp <sven.langkamp@gmail.com>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; version 2.1 of the License.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "channelmodel.h"
 #include <QImage>
 #include <KoColorSpace.h>
 #include <KoChannelInfo.h>
+#include <KoColorModelStandardIds.h>
+
 #include <kis_painter.h>
 
 #include <kis_group_layer.h>
@@ -48,30 +39,33 @@ QVariant ChannelModel::data(const QModelIndex& index, int role) const
 
         int channelIndex = index.row();
 
-        switch (role) {
-        case Qt::DisplayRole: {
-            if (index.column() == 2) {
-                return channels.at(channelIndex)->name();
-            }
-            return QVariant();
-        }
-        case Qt::DecorationRole: {
-            if (index.column() == 1) {
-                Q_ASSERT(m_thumbnails.count() > index.row());
-                return QVariant(m_thumbnails.at(index.row()));
-            }
-            return QVariant();
-        }
-        case Qt::CheckStateRole: {
-            Q_ASSERT(index.row() < rowCount());
-            Q_ASSERT(index.column() < columnCount());
+        if (index.row() < m_channelCount) {
 
-            if (index.column() == 0) {
-                QBitArray flags = rootLayer->channelFlags();
-                return (flags.isEmpty() || flags.testBit(channelIndex)) ? Qt::Checked : Qt::Unchecked;
+            switch (role) {
+            case Qt::DisplayRole: {
+                if (index.column() == 2) {
+                    return channels.at(channelIndex)->name();
+                }
+                return QVariant();
+            }
+            case Qt::DecorationRole: {
+                if (index.column() == 1) {
+                    Q_ASSERT(m_thumbnails.count() > index.row());
+                    return QVariant(m_thumbnails.at(index.row()));
+                }
+                return QVariant();
+            }
+            case Qt::CheckStateRole: {
+                Q_ASSERT(index.row() < rowCount());
+                Q_ASSERT(index.column() < columnCount());
+
+                if (index.column() == 0) {
+                    QBitArray flags = rootLayer->channelFlags();
+                    return (flags.isEmpty() || flags.testBit(channelIndex)) ? Qt::Checked : Qt::Unchecked;
+                }
+                return QVariant();
+            }
             }
-            return QVariant();
-        }
         }
     }
     return QVariant();
@@ -231,27 +225,25 @@ void ChannelModel::updateThumbnails(void)
         m_thumbnails.resize(m_channelCount);
 
         for (quint32 i = 0; i < (quint32)m_channelCount; ++i) {
-#if QT_VERSION >= 0x050500
             m_thumbnails[i] = QImage(thumbnailSize, QImage::Format_Grayscale8);
-#else
-            m_thumbnails[i] = QImage(thumbnailSize, QImage::Format_ARGB32_Premultiplied);
-#endif
         }
 
         KisSequentialConstIterator it(thumbnailDev, QRect(0, 0, thumbnailSize.width(), thumbnailSize.height()));
 
+        bool invert = (cs->colorModelId() == CMYKAColorModelID);
+
         for (int y = 0; y < thumbnailSize.height(); y++) {
             for (int x = 0; x < thumbnailSize.width(); x++) {
                 it.nextPixel();
                 const quint8* pixel = it.rawDataConst();
                 for (int chan = 0; chan < m_channelCount; ++chan) {
                     QImage &img = m_thumbnails[chan];
-#if QT_VERSION >= 0x050500
-                    *(img.scanLine(y) + x) = cs->scaleToU8(pixel, chan);
-#else
-                    quint8 v = cs->scaleToU8(pixel, chan);
-                    img.setPixel(x, y, qRgb(v, v, v));
-#endif
+                    if (invert) {
+                        *(img.scanLine(y) + x) = 255 - cs->scaleToU8(pixel, chan);
+                    }
+                    else {
+                        *(img.scanLine(y) + x) = cs->scaleToU8(pixel, chan);
+                    }
                 }
             }
         }
