@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
  *
-   Copyright 2017 Boudewijn Rempt <boud@valdyas.org>
+   SPDX-FileCopyrightText: 2017 Boudewijn Rempt <boud@valdyas.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef SVG_TEXT_TOOL
@@ -26,6 +13,9 @@
 #include <QPushButton>
 #include <QFontComboBox>
 #include <QPointer>
+#include <QDoubleSpinBox>
+
+#include "SvgTextEditor.h"
 
 class KoSelection;
 class SvgTextEditor;
@@ -51,13 +41,15 @@ public:
     void keyPressEvent(QKeyEvent *event) override;
 
     /// reimplemented from KoToolBase
-    void activate(ToolActivation activation, const QSet<KoShape *> &shapes) override;
+    void activate(const QSet<KoShape *> &shapes) override;
     /// reimplemented from KoToolBase
     void deactivate() override;
 
+    KisPopupWidgetInterface* popupWidget() override;
+
 protected:
     /// reimplemented from KoToolBase
-    virtual QWidget *createOptionWidget();
+    virtual QWidget *createOptionWidget() override;
 
     KoSelection *koSelection() const;
     KoSvgTextShape *selectedShape() const;
@@ -65,7 +57,8 @@ protected:
 private Q_SLOTS:
 
     void showEditor();
-    void textUpdated(KoSvgTextShape *shape, const QString &svg, const QString &defs);
+    void slotTextEditorClosed();
+    void textUpdated(KoSvgTextShape *shape, const QString &svg, const QString &defs, bool richTextUpdated);
 
     /**
      * @brief generateDefs
@@ -84,16 +77,18 @@ private Q_SLOTS:
 
 private:
     QPointer<SvgTextEditor> m_editor;
-    QPushButton *m_edit;
-    QPointF m_dragStart;
-    QPointF m_dragEnd;
-    bool m_dragging;
-    QFontComboBox *m_defFont;
-    QComboBox *m_defPointSize;
-    QButtonGroup *m_defAlignment;
+    QPushButton *m_edit {nullptr};
+    QPointF m_dragStart {QPointF(0, 0)};
+    QPointF m_dragEnd {QPointF(0, 0)};
+    bool m_dragging {false};
+    QFontComboBox *m_defFont {nullptr};
+    QComboBox *m_defPointSize {nullptr};
+    QButtonGroup *m_defAlignment {nullptr};
+    QDoubleSpinBox *m_defLetterSpacing {nullptr};
     KConfigGroup m_configGroup;
 
     QRectF m_hoveredShapeHighlightRect;
+    boost::optional<KoColor> m_originalColor { boost::none };
 };
 
 #endif
