@@ -1,23 +1,13 @@
 /*
- *  Copyright (c) 2014 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2014 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
-
 #include "kis_liquify_paint_helper.h"
 
+#include <QElapsedTimer>
+#include <QPainterPath>
+
 #include "kis_algebra_2d.h"
 #include "KoPointerEvent.h"
 #include <brushengine/kis_paint_information.h>
@@ -44,7 +34,7 @@ struct KisLiquifyPaintHelper::Private
     const KisCoordinatesConverter *converter;
     QScopedPointer<KisPaintingInformationBuilder> infoBuilder;
 
-    QTime strokeTime;
+    QElapsedTimer strokeTime;
 
     bool hasPaintedAtLeastOnce;
 
@@ -65,7 +55,7 @@ KisLiquifyPaintHelper::~KisLiquifyPaintHelper()
 
 void KisLiquifyPaintHelper::Private::updatePreviousPaintInfo(const KisPaintInformation &info)
 {
-    QPointF prevPos = lastOutlinePos.pushThroughHistory(info.pos());
+    QPointF prevPos = lastOutlinePos.pushThroughHistory(info.pos(), converter->effectiveZoom());
     qreal angle = KisAlgebra2D::directionBetweenPoints(prevPos, info.pos(), 0);
 
     previousDistanceInfo =
@@ -88,7 +78,7 @@ void KisLiquifyPaintHelper::configurePaintOp(const KisLiquifyProperties &props,
     m_d->paintOp.reset(new KisLiquifyPaintop(props, worker));
 }
 
-void KisLiquifyPaintHelper::startPaint(KoPointerEvent *event, const KoCanvasResourceManager *manager)
+void KisLiquifyPaintHelper::startPaint(KoPointerEvent *event, const KoCanvasResourceProvider *manager)
 {
     KIS_ASSERT_RECOVER_RETURN(m_d->paintOp);
 
@@ -136,7 +126,7 @@ bool KisLiquifyPaintHelper::endPaint(KoPointerEvent *event)
 void KisLiquifyPaintHelper::hoverPaint(KoPointerEvent *event)
 {
     QPointF imagePoint = m_d->converter->documentToImage(event->pos());
-    KisPaintInformation pi = m_d->infoBuilder->hover(imagePoint, event);
+    KisPaintInformation pi = m_d->infoBuilder->hover(imagePoint, event, m_d->paintOp);
 
     m_d->updatePreviousPaintInfo(pi);
 }
